/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.model.sinfo;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.dive4elements.river.model.River;

/**
 * Hibernate binding for the DB table channel
 *
 * @author Matthias Schäfer
 *
 */


@Entity
@Table(name = "channel")
public class Channel implements Serializable {

    /***** FIELDS *****/

    private static final long serialVersionUID = 4845405421049630551L;

    private Integer id;

    private River river;

    private String kmrange_info;

    private String filename;

    private String comment;

    private Integer year_from;

    private Integer year_to;

    private List<ChannelValue> values;


    /***** CONSTRUCTORS *****/

    public Channel() {
    }

    public Channel(final River river, final String filename, final String kmrange_info, final String comment, final Integer year_from, final Integer year_to) {
        this.river = river;
        this.filename = filename;
        this.kmrange_info = kmrange_info;
        this.comment = comment;
        this.setYear_from(year_from);
        this.setYear_to(year_to);
        this.values = new ArrayList<>();
    }

    /***** METHODS *****/

    @Id
    @SequenceGenerator(name = "SEQUENCE_CHANNEL_ID_SEQ", sequenceName = "CHANNEL_ID_SEQ", allocationSize = 1)
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQUENCE_CHANNEL_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return this.id;
    }

    public void setId(final Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "river_id")
    public River getRiver() {
        return this.river;
    }

    public void setRiver(final River river) {
        this.river = river;
    }

    @Column(name = "filename")
    public String getFilename() {
        return this.filename;
    }

    public void setFilename(final String filename) {
        this.filename = filename;
    }

    @Column(name = "kmrange_info")
    public String getKmrange_info() {
        return this.kmrange_info;
    }

    public void setKmrange_info(final String kmrange_info) {
        this.kmrange_info = kmrange_info;
    }

    @Column(name = "comment")
    public String getComment() {
        return this.comment;
    }

    public void setComment(final String comment) {
        this.comment = comment;
    }

    @Column(name = "year_from")
    public Integer getYear_from() {
        return this.year_from;
    }

    public void setYear_from(final Integer year_from) {
        this.year_from = year_from;
    }

    @Column(name = "year_to")
    public Integer getYear_to() {
        return this.year_to;
    }

    public void setYear_to(final Integer year_to) {
        this.year_to = year_to;
    }

    @OneToMany
    @JoinColumn(name = "channel_id")
    public List<ChannelValue> getValues() {
        return this.values;
    }

    public void setValues(final List<ChannelValue> values) {
        this.values = values;
    }

    public void addValue(final ChannelValue value) {
        this.values.add(value);
    }
}